[![PyPI version](https://badge.fury.io/py/mlfarm.svg)](https://badge.fury.io/py/mlfarm) [![Documentation Status](https://readthedocs.org/projects/mlfarm/badge/?version=stable)](https://mlfarm.readthedocs.io/en/latest/?badge=stable) [![Build Status](https://dev.azure.com/mlfarm/mlfarm/_apis/build/status/MLFarm.CI.Test?branchName=release)](https://dev.azure.com/mlfarm/mlfarm/_build/latest?definitionId=1&branchName=release)

# MLFarm

This package contains a suite of tools to be used for fast development of new Machine Learning projects.